'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var _rollupPluginBabelHelpers = require('./_virtual/_rollupPluginBabelHelpers.cjs');
var jsCore = require('@lorisleiva/js-core');

const DEFAULT_BASE_URL = 'https://mockstorage.example.com/';
class MockStorage {
  constructor(options) {
    _rollupPluginBabelHelpers.defineProperty(this, "cache", {});
    this.baseUrl = options?.baseUrl ?? DEFAULT_BASE_URL;
  }
  async uploadOne(file) {
    const uri = `${this.baseUrl}${file.uniqueName}`;
    this.cache[uri] = file;
    return uri;
  }
  async upload(files) {
    return Promise.all(files.map(file => this.uploadOne(file)));
  }
  async download(uris) {
    return Promise.all(uris.map(uri => this.downloadOne(uri)));
  }
  async downloadOne(uri) {
    const file = this.cache[uri];
    if (!file) {
      throw new jsCore.AssetNotFoundError(uri);
    }
    return file;
  }
}

exports.MockStorage = MockStorage;
//# sourceMappingURL=MockStorage.cjs.map
